==> alfresco-repository-23.7.0.8-sources.jar: org/alfresco/repo/security/sync/TestableChainingUserRegistrySynchronizer.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.security.sync;

import org.alfresco.repo.security.authentication.AuthenticationException;

public interface TestableChainingUserRegistrySynchronizer
{
    /**
     * runs read only diagnostic tests upon the specified user directory, does not actually do any synchronization
     * 
     * @param authenticatorName name of the user directory to test
     * @return diagnostic information @see org.alfresco.repo.security.sync.SynchronizeDiagnostic
     * @throws AuthenticationException
     */
    public SynchronizeDiagnostic testSynchronize(String authenticatorName);
  
}

==> alfresco-repository-25.4.0.2-sources.jar: org/alfresco/repo/security/sync/TestableChainingUserRegistrySynchronizer.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.security.sync;

import org.alfresco.repo.security.authentication.AuthenticationException;

public interface TestableChainingUserRegistrySynchronizer
{
    /**
     * runs read only diagnostic tests upon the specified user directory, does not actually do any synchronization
     * 
     * @param authenticatorName
     *            name of the user directory to test
     * @return diagnostic information @see org.alfresco.repo.security.sync.SynchronizeDiagnostic
     * @throws AuthenticationException
     */
    public SynchronizeDiagnostic testSynchronize(String authenticatorName);

}
